{% load i18n %}

<style>
ol > li::marker {
  font-weight: bold;
}
ol > li {
  margin: 2em, 0;
}
</style>

<h4>Using web service facilities at {{ settings.SITE_PUBLISHER }} </h4>
<hr>
<ol>
  <li>
    <p>
    Registering for use of a web service at {{ settings.SITE_PUBLISHER }} is creating an account for the web service.<br>
    A registered user is provided with a limited storage space to cache their results from
    queries to data provided via this web service.
    </p>
  </li>

  <li>
    <p>
    The allocation of storage and tools is provided for scientific uses.<br>
    The user can access these data (mostly database tables) to explore and
    refine their queries into the data, extract suitable parts of these data for
    downloading to other storage location.<br>
    The usage includes the management of the allocated storage space by the registered user
    by provided means (via TAP protocol or web interface).
    </p>
  </li>

  <li>
    <p>
    The {{ settings.SITE_PUBLISHER }} reserves the right to remove the allocated storage
      <ul>
        <li>if this is used for illegal, commercial or other private purposes,</li>
        <li>the user is using the provided account for attacking the service.</li>
      </ul>
    <br>
    The {{ settings.SITE_PUBLISHER }} also reserves the right to terminate the account unlaterally without recourse
    if the usage is deemed harmful or unlawful.
    </p>
  </li>

  <li>
    <p>
    For creating the user account only minimal personal data is collected.<br>
    The collected personal data is neither used for other than the stated means,
    nor will these data made available to third parties.
    </p>
  </li>

  <li>
    <p>
    Neither the {{ settings.SITE_PUBLISHER }} , nor the web service providers shall be held accountable for any
    loss of data or data integrity of the user's storage space.<br>
    No guarantee is provided that login is possible at all times.<br>
    The service is offered on a best effort basis.
    </p>
  </li>

  <li>
    <p>
    By acknowledging these terms, the user is consenting to the above statements.
    </p>
  </li>
</ol>
