# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-10-25 10:11
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_metadata', '0014_rename_pid_to_doi'),
    ]

    operations = [
        migrations.AlterField(
            model_name='database',
            name='doi',
            field=models.CharField(blank=True, max_length=256, null=True, verbose_name='Digital object identifier'),
        ),
        migrations.AlterField(
            model_name='table',
            name='doi',
            field=models.CharField(blank=True, max_length=256, null=True, verbose_name='Digital object identifier'),
        ),
    ]
