# Generated by Django 2.2.8 on 2020-01-24 10:31

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_oai', '0002_resource_type'),
    ]

    operations = [
        migrations.AddField(
            model_name='record',
            name='set_spec',
            field=models.CharField(blank=True, db_index=True, max_length=256, verbose_name='OAI set spec'),
        ),
    ]
