{% if announcements %}
    {% for msg in announcements %}
    <div class="alert alert-{{ msg.announcement_type }}"
        role="alert">
        {{ msg.announcement | safe }}
    </div>
    {% endfor %}
{% endif %}
