# Generated by Django 3.2.12 on 2022-02-11 18:55

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_oai', '0005_alter_record_resource_id'),
    ]

    operations = [
        migrations.AlterField(
            model_name='record',
            name='resource_id',
            field=models.CharField(blank=True, db_index=True, default='', max_length=256, verbose_name='Resource id'),
            preserve_default=False,
        ),
    ]
