# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2016-07-05 13:02
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('auth', '0007_alter_validators_add_error_messages'),
        ('daiquiri_metadata', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='column',
            name='published_for',
            field=models.ManyToManyField(blank=True, to='auth.Group'),
        ),
        migrations.AddField(
            model_name='database',
            name='published_for',
            field=models.ManyToManyField(blank=True, to='auth.Group'),
        ),
        migrations.AddField(
            model_name='function',
            name='published_for',
            field=models.ManyToManyField(blank=True, to='auth.Group'),
        ),
        migrations.AddField(
            model_name='table',
            name='published_for',
            field=models.ManyToManyField(blank=True, to='auth.Group'),
        ),
    ]
