# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2017-04-13 10:25
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_contact', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='contactmessage',
            options={'ordering': ('status', 'created', 'author'), 'verbose_name': 'Contact message', 'verbose_name_plural': 'Contact messages'},
        ),
        migrations.AlterField(
            model_name='contactmessage',
            name='status',
            field=models.CharField(choices=[('ACTIVE', 'active'), ('CLOSED', 'closed'), ('SPAM', 'spam')], max_length=8),
        ),
    ]
