# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2017-04-13 14:31
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_query', '0008_queryjob_pid'),
    ]

    operations = [
        migrations.AlterField(
            model_name='queryjob',
            name='query_language',
            field=models.CharField(max_length=8),
        ),
        migrations.AlterField(
            model_name='queryjob',
            name='queue',
            field=models.CharField(max_length=16),
        ),
    ]
