# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2016-03-10 16:15
from __future__ import unicode_literals

from django.db import migrations
import jsonfield.fields


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_auth', '0001_profile_model'),
    ]

    operations = [
        migrations.AddField(
            model_name='profile',
            name='attributes',
            field=jsonfield.fields.JSONField(blank=True, null=True),
        ),
    ]
