# Generated by Django 2.1.3 on 2018-11-05 16:59

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_contact', '0004_meta'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='contactmessage',
            options={'ordering': ('-created', 'author'), 'verbose_name': 'Contact message', 'verbose_name_plural': 'Contact messages'},
        ),
    ]
