# Generated by Django 2.1.3 on 2018-11-05 16:59

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_files', '0003_python3'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='directory',
            options={'ordering': ('path',), 'verbose_name': 'Directory', 'verbose_name_plural': 'Directory'},
        ),
    ]
