# -*- coding: utf-8 -*-
# Generated by Django 1.11.10 on 2018-02-16 16:50
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_query', '0015_queryarchivejob'),
    ]

    operations = [
        migrations.RenameField(
            model_name='queryjob',
            old_name='database_name',
            new_name='schema_name',
        ),
    ]
