# Generated by Django 2.1.4 on 2019-05-29 13:44

from django.db import migrations
import jsonfield.fields


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_metadata', '0025_add_published_updated'),
    ]

    operations = [
        migrations.AddField(
            model_name='schema',
            name='contributors',
            field=jsonfield.fields.JSONField(blank=True, null=True, verbose_name='Contributors'),
        ),
        migrations.AddField(
            model_name='schema',
            name='creators',
            field=jsonfield.fields.JSONField(blank=True, null=True, verbose_name='Creators'),
        ),
        migrations.AddField(
            model_name='table',
            name='contributors',
            field=jsonfield.fields.JSONField(blank=True, null=True, verbose_name='Contributors'),
        ),
        migrations.AddField(
            model_name='table',
            name='creators',
            field=jsonfield.fields.JSONField(blank=True, null=True, verbose_name='Creators'),
        ),
    ]
