# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2016-03-11 16:57
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_auth', '0005_view_permission_fix'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='profile',
            options={'ordering': ('user__last_name', 'user__last_name', 'user__username'), 'permissions': (('view_profile', 'Can view Profile'),), 'verbose_name': 'Profile', 'verbose_name_plural': 'Profiles'},
        ),
    ]
