# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2017-07-21 12:33
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_query', '0012_query_language_length'),
    ]

    operations = [
        migrations.AddField(
            model_name='example',
            name='access_level',
            field=models.CharField(choices=[(b'PRIVATE', 'Private - access must be granted by group'), (b'INTERNAL', 'Internal - logged in users can access'), (b'PUBLIC', 'Public - anonymous visitors can access')], default='PRIVATE', max_length=8, verbose_name='Access level'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='example',
            name='query_language',
            field=models.CharField(default='adql-2.0', help_text='The query language for this example.', max_length=16, verbose_name='Query language'),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='example',
            name='description',
            field=models.TextField(blank=True, help_text='A brief description of the example to be displayed in the user interface.', null=True, verbose_name='Description'),
        ),
        migrations.AlterField(
            model_name='example',
            name='groups',
            field=models.ManyToManyField(blank=True, help_text='The groups which have access to the examples.', to='auth.Group', verbose_name='Groups'),
        ),
        migrations.AlterField(
            model_name='example',
            name='name',
            field=models.CharField(help_text='Identifier of the example.', max_length=256, verbose_name='Name'),
        ),
        migrations.AlterField(
            model_name='example',
            name='order',
            field=models.IntegerField(blank=True, help_text='Position in lists.', null=True, verbose_name='Order'),
        ),
        migrations.AlterField(
            model_name='example',
            name='query_string',
            field=models.TextField(help_text='The query string (SQL) for this example.', verbose_name='Query string'),
        ),
    ]
