# Generated by Django 3.2.12 on 2022-03-16 11:29

import daiquiri.core.encoders
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_stats', '0007_use_django_jsonfield'),
    ]

    operations = [
        migrations.AlterField(
            model_name='record',
            name='resource',
            field=models.JSONField(encoder=daiquiri.core.encoders.UUIDJSONEncoder),
        ),
    ]
