# -*- coding: utf-8 -*-
# Generated by Django 1.11.5 on 2017-12-09 14:59
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_jobs', '0012_meta'),
        ('daiquiri_query', '0013_refactoring'),
    ]

    operations = [
        migrations.CreateModel(
            name='DownloadJob',
            fields=[
                ('job_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='daiquiri_jobs.Job')),
                ('format_key', models.CharField(help_text='Format key for this download.', max_length=32, verbose_name='Format key')),
                ('file_path', models.CharField(help_text='Path to the file.', max_length=256, verbose_name='Path')),
                ('job', models.ForeignKey(help_text='QueryJob this DownloadJob belongs to.', on_delete=django.db.models.deletion.CASCADE, related_name='downloads', to='daiquiri_query.QueryJob', verbose_name='QueryJob')),
            ],
            options={
                'ordering': ('start_time',),
                'verbose_name': 'DownloadJob',
                'verbose_name_plural': 'DownloadJobs',
                'permissions': (('view_downloadjob', 'Can view DownloadJob'),),
            },
            bases=('daiquiri_jobs.job',),
        ),
    ]
