# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2017-02-13 12:25
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='ContactMessage',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('author', models.CharField(max_length=256)),
                ('email', models.EmailField(max_length=256)),
                ('subject', models.CharField(max_length=256)),
                ('status', models.CharField(choices=[('STATUS_ACTIVE', 'active'), ('STATUS_CLOSED', 'closed')], max_length=8)),
                ('created', models.DateTimeField(blank=True, null=True)),
                ('message', models.TextField()),
                ('user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='contact_messages', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'ordering': ('created', 'status'),
                'verbose_name': 'Contact message',
                'verbose_name_plural': 'Contact messages',
            },
        ),
    ]
