{% load i18n %}

<p>
    {% blocktrans %}
    Place your SQL statement directly in the text area below and submit your request using the button. You can use the dropdown menus to get information about the database, to query external services or to access example queries.
    {% endblocktrans %}
</p>

<p>
    {% blocktrans %}
    Optionally, you can specify the name of the resulting database table and/or assign a run id, to group associated queries in the job list. Please choose a queue with a suitable timeout for your query.
    {% endblocktrans %}
</p>
