# Generated by Django 4.0.8 on 2022-11-14 11:17

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_datalink', '0002_alter_datalink_content_length'),
    ]

    operations = [
        migrations.AlterField(
            model_name='datalink',
            name='content_length',
            field=models.BigIntegerField(null=True, verbose_name='Content length'),
        ),
    ]
