# Generated by Django 3.2.10 on 2022-01-10 16:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_metadata', '0029_alter_ids'),
    ]

    operations = [
        migrations.AlterField(
            model_name='schema',
            name='license',
            field=models.CharField(blank=True, max_length=8, null=True, verbose_name='License'),
        ),
        migrations.AlterField(
            model_name='table',
            name='license',
            field=models.CharField(blank=True, max_length=8, null=True, verbose_name='License'),
        ),
    ]
