# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2017-06-02 13:27
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_contact', '0002_meta'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='contactmessage',
            options={'ordering': ('status', 'created', 'author'), 'permissions': (('view_contactmessage', 'Can view ContactMessage'),), 'verbose_name': 'Contact message', 'verbose_name_plural': 'Contact messages'},
        ),
    ]
