{% extends 'core/base.html' %}

{% block content %}

<div class="container">
    <hgroup>
        {% block heading %}{% endblock %}
    </hgroup>

    <div class="row">
        <main class="col-md-9">
            {% block page %}{% endblock %}
        </main>
        <aside class="col-md-3">
            {% block sidebar %}{% endblock %}
        </aside>
    </div>
</div>

{% endblock %}
