STATS_RESOURCE_TYPES = [
    {
        'key': 'CONESEARCH',
        'label': 'Performed cone searches'
    },
    {
        'key': 'CUTOUT',
        'label': 'Performed cutouts'
    },
    {
        'key': 'FILE',
        'label': 'Downloaded static files'
    },
    {
        'key': 'CREATE_ZIP',
        'label': 'Created zip files'
    },
    {
        'key': 'CREATE_FILE',
        'label': 'Created files for download'
    },
    {
        'key': 'DOWNLOAD',
        'label': 'Downloaded files'
    },
    {
        'key': 'UPLOAD',
        'label': 'Uploaded files'
    },
    {
        'key': 'QUERY',
        'label': 'Queries'
    },
]
