{% extends 'core/wide.html' %}
{% load static %}

{% block js %}
    <script src="{% url 'javascript-catalog' %}"></script>
    <script src="{% static 'auth/js/users.js' %}" defer="defer"></script>
{% endblock %}

{% block wide %}

    <h1>User management</h1>

    <div id="app" class="users"></div>

{% endblock %}
