# Generated by Django 3.2.10 on 2022-01-22 13:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_files', '0006_alter_directory_id'),
    ]

    operations = [
        migrations.AlterField(
            model_name='directory',
            name='layout',
            field=models.BooleanField(default=True, help_text='Use the page layout with the content.', verbose_name='Layout'),
        ),
    ]
