{% load static %}<!DOCTYPE html>
<html>

<head>

{% include 'core/base_head.html' %}

{% block css %}
<link rel="stylesheet" href="{% static 'core/css/bootstrap.css' %}" type="text/css" />
<link rel="stylesheet" href="{% static 'core/css/base.css' %}" type="text/css" />
<link rel="stylesheet" href="{% static 'core/css/style.css' %}" type="text/css" />
{% endblock %}

{% block js %}
<script src="{% static 'core/js/bootstrap.js' %}" defer="defer"></script>
{% endblock %}

</head>

<body>

{% include 'core/base_navigation.html' %}

<div class="content">
{% block content %}{% endblock %}
</div>

{% include 'core/base_footer.html' %}

{% if not debug %}{% include 'core/base_analytics.html' %}{% endif %}
</body>

</html>
