{% load i18n %}

<div class="card mb-3">
    <div class="card-header">{% trans 'Access' %}</div>
    <div class="card-body">
        <p>
            {% url 'query:query' as query_url %}
            {% blocktrans %}
            You can access this {{ dataset }} using the <a href="{{ query_url }}">query interface</a> and download the results afterwards.
            {% endblocktrans %}
        </p>
    </div>
</div>
