.form-label{font-size:small;margin-bottom:.25rem}.query-jobs .list-group{max-height:400px;overflow-y:auto}.query-jobs .list-group button.btn-link{background-color:var(--bs-light)}.query-form .codemirror .cm-content,.query-form .codemirror .cm-gutter{min-height:15rem}.query-download h3{margin-bottom:1rem}
