{% extends 'core/wide.html' %}
{% load static %}

{% block js %}
<script src="{% url 'javascript-catalog' %}"></script>
<script src="{% static 'contact/js/messages.js' %}" defer="defer"></script>
{% endblock %}

{% block wide %}

    <h1>Contact messages</h1>

    <div id="app" class="messages"></div>

{% endblock %}
