# Generated by Django 3.2.12 on 2022-02-04 14:57

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_stats', '0006_alter_record_id'),
    ]

    operations = [
        migrations.AlterField(
            model_name='record',
            name='resource',
            field=models.JSONField(),
        ),
    ]
