# -*- coding: utf-8 -*-
# Generated by Django 1.11.12 on 2018-05-29 14:31
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_jobs', '0014_blank_run_id'),
    ]

    operations = [
        migrations.AlterField(
            model_name='job',
            name='creation_time',
            field=models.DateTimeField(blank=True, db_index=True, null=True),
        ),
        migrations.AlterField(
            model_name='job',
            name='phase',
            field=models.CharField(choices=[('PENDING', 'Pending'), ('QUEUED', 'Queued'), ('EXECUTING', 'Executing'), ('COMPLETED', 'Completed'), ('ERROR', 'Error'), ('ABORTED', 'Aborted'), ('UNKNOWN', 'Unknown'), ('HELD', 'Held'), ('SUSPENDED', 'Suspended'), ('ARCHIVED', 'Archived')], db_index=True, max_length=10),
        ),
        migrations.AlterField(
            model_name='job',
            name='run_id',
            field=models.CharField(blank=True, db_index=True, default='', max_length=64),
        ),
    ]
