# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2016-10-13 15:25
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_query', '0002_meta'),
    ]

    operations = [
        migrations.AlterModelManagers(
            name='queryjob',
            managers=[
            ],
        ),
        migrations.AddField(
            model_name='queryjob',
            name='actual_query',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='queryjob',
            name='query_language',
            field=models.CharField(choices=[('adql', 'ADQL'), ('mysql', 'MySQL SQL')], default='mysql', max_length=8),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='queryjob',
            name='queue',
            field=models.CharField(choices=[('default', 'Default')], max_length=16),
        ),
    ]
