# -*- coding: utf-8 -*-
# Generated by Django 1.11.12 on 2018-05-16 11:20
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_auth', '0010_profile_consent'),
    ]

    operations = [
        migrations.AlterField(
            model_name='profile',
            name='is_confirmed',
            field=models.BooleanField(default=False, help_text='Designates whether the user was confirmed by a manager.'),
        ),
        migrations.AlterField(
            model_name='profile',
            name='is_pending',
            field=models.BooleanField(default=False, help_text='Designates whether the user waiting on confirmation by a manager.'),
        ),
    ]
