# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-08-30 14:59
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('auth', '0008_alter_user_username_max_length'),
        ('daiquiri_metadata', '0010_meta'),
    ]

    operations = [
        migrations.CreateModel(
            name='Directory',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('path', models.CharField(help_text='Path of the directory.', max_length=256, verbose_name='Path')),
                ('access_level', models.CharField(choices=[(b'PRIVATE', 'Private - access must be granted by group'), (b'INTERNAL', 'Internal - logged in users can access'), (b'PUBLIC', 'Public - anonymous visitors can access')], max_length=8, verbose_name='Access level')),
                ('metadata_access_level', models.CharField(choices=[(b'PRIVATE', 'Private - access must be granted by group'), (b'INTERNAL', 'Internal - logged in users can access'), (b'PUBLIC', 'Public - anonymous visitors can access')], max_length=8, verbose_name='Metadata access level')),
                ('groups', models.ManyToManyField(blank=True, help_text='The groups which have access to this function.', to='auth.Group', verbose_name='Groups')),
            ],
            options={
                'ordering': ('path',),
                'verbose_name': 'Directory',
                'verbose_name_plural': 'Directory',
                'permissions': (('view_function', 'Can view Directory'),),
            },
        ),
    ]
