# Generated by Django 3.2.12 on 2022-02-04 14:02

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_metadata', '0032_data_migration'),
    ]

    operations = [
        migrations.AlterField(
            model_name='column',
            name='access_level',
            field=models.CharField(choices=[('PRIVATE', 'Private - access must be granted by group'), ('INTERNAL', 'Internal - logged in users can access'), ('PUBLIC', 'Public - anonymous visitors can access')], default='PRIVATE', max_length=8, verbose_name='Access level'),
        ),
        migrations.AlterField(
            model_name='column',
            name='datatype',
            field=models.CharField(blank=True, default='', help_text='The datatype of the column on the database server.', max_length=256, verbose_name='Datatype'),
        ),
        migrations.AlterField(
            model_name='column',
            name='description',
            field=models.TextField(blank=True, default='', help_text='A brief description of the column to be displayed in the user interface.', verbose_name='Description'),
        ),
        migrations.AlterField(
            model_name='column',
            name='metadata_access_level',
            field=models.CharField(choices=[('PRIVATE', 'Private - access must be granted by group'), ('INTERNAL', 'Internal - logged in users can access'), ('PUBLIC', 'Public - anonymous visitors can access')], default='PRIVATE', max_length=8, verbose_name='Metadata access level'),
        ),
        migrations.AlterField(
            model_name='column',
            name='ucd',
            field=models.CharField(blank=True, default='', max_length=256, verbose_name='IVOA UCDs'),
        ),
        migrations.AlterField(
            model_name='column',
            name='unit',
            field=models.CharField(blank=True, default='', max_length=256, verbose_name='Unit'),
        ),
        migrations.AlterField(
            model_name='column',
            name='utype',
            field=models.CharField(blank=True, default='', max_length=256, verbose_name='IVOA Utype'),
        ),
        migrations.AlterField(
            model_name='function',
            name='access_level',
            field=models.CharField(choices=[('PRIVATE', 'Private - access must be granted by group'), ('INTERNAL', 'Internal - logged in users can access'), ('PUBLIC', 'Public - anonymous visitors can access')], default='PRIVATE', max_length=8, verbose_name='Access level'),
        ),
        migrations.AlterField(
            model_name='function',
            name='description',
            field=models.TextField(blank=True, default='', help_text='A brief description of the function to be displayed in the user interface.', verbose_name='Description'),
        ),
        migrations.AlterField(
            model_name='function',
            name='metadata_access_level',
            field=models.CharField(choices=[('PRIVATE', 'Private - access must be granted by group'), ('INTERNAL', 'Internal - logged in users can access'), ('PUBLIC', 'Public - anonymous visitors can access')], default='PRIVATE', max_length=8, verbose_name='Metadata access level'),
        ),
        migrations.AlterField(
            model_name='schema',
            name='access_level',
            field=models.CharField(choices=[('PRIVATE', 'Private - access must be granted by group'), ('INTERNAL', 'Internal - logged in users can access'), ('PUBLIC', 'Public - anonymous visitors can access')], default='PRIVATE', max_length=8, verbose_name='Access level'),
        ),
        migrations.AlterField(
            model_name='schema',
            name='attribution',
            field=models.TextField(blank=True, default='', help_text='The desired attribution for the schema.', verbose_name='Attribution'),
        ),
        migrations.AlterField(
            model_name='schema',
            name='contributors',
            field=models.JSONField(blank=True, default=list, verbose_name='Contributors'),
        ),
        migrations.AlterField(
            model_name='schema',
            name='creators',
            field=models.JSONField(blank=True, default=list, verbose_name='Creators'),
        ),
        migrations.AlterField(
            model_name='schema',
            name='description',
            field=models.TextField(blank=True, default='', help_text='A brief description of the schema to be displayed in the user interface.', verbose_name='Description'),
        ),
        migrations.AlterField(
            model_name='schema',
            name='doi',
            field=models.CharField(blank=True, default='', max_length=256, verbose_name='Digital object identifier'),
        ),
        migrations.AlterField(
            model_name='schema',
            name='license',
            field=models.CharField(blank=True, default='', max_length=8, verbose_name='License'),
        ),
        migrations.AlterField(
            model_name='schema',
            name='long_description',
            field=models.TextField(blank=True, default='', help_text='A more extensive description of the schema to be displayed on the public schema page.', verbose_name='Long description'),
        ),
        migrations.AlterField(
            model_name='schema',
            name='metadata_access_level',
            field=models.CharField(choices=[('PRIVATE', 'Private - access must be granted by group'), ('INTERNAL', 'Internal - logged in users can access'), ('PUBLIC', 'Public - anonymous visitors can access')], default='PRIVATE', max_length=8, verbose_name='Metadata access level'),
        ),
        migrations.AlterField(
            model_name='schema',
            name='related_identifiers',
            field=models.JSONField(blank=True, default=list, verbose_name='Related Identifiers'),
        ),
        migrations.AlterField(
            model_name='schema',
            name='title',
            field=models.CharField(blank=True, default='', help_text='Human readable title of the schema.', max_length=256, verbose_name='Title'),
        ),
        migrations.AlterField(
            model_name='schema',
            name='utype',
            field=models.CharField(blank=True, default='', max_length=256, verbose_name='IVOA Utype'),
        ),
        migrations.AlterField(
            model_name='table',
            name='access_level',
            field=models.CharField(choices=[('PRIVATE', 'Private - access must be granted by group'), ('INTERNAL', 'Internal - logged in users can access'), ('PUBLIC', 'Public - anonymous visitors can access')], default='PRIVATE', max_length=8, verbose_name='Access level'),
        ),
        migrations.AlterField(
            model_name='table',
            name='attribution',
            field=models.TextField(blank=True, default='', help_text='The desired attribution for the table.', verbose_name='Attribution'),
        ),
        migrations.AlterField(
            model_name='table',
            name='contributors',
            field=models.JSONField(blank=True, default=list, verbose_name='Contributors'),
        ),
        migrations.AlterField(
            model_name='table',
            name='creators',
            field=models.JSONField(blank=True, default=list, verbose_name='Creators'),
        ),
        migrations.AlterField(
            model_name='table',
            name='description',
            field=models.TextField(blank=True, default='', help_text='A brief description of the table to be displayed in the user interface.', verbose_name='Description'),
        ),
        migrations.AlterField(
            model_name='table',
            name='doi',
            field=models.CharField(blank=True, default='', max_length=256, verbose_name='Digital object identifier'),
        ),
        migrations.AlterField(
            model_name='table',
            name='license',
            field=models.CharField(blank=True, default='', max_length=8, verbose_name='License'),
        ),
        migrations.AlterField(
            model_name='table',
            name='long_description',
            field=models.TextField(blank=True, default='', help_text='A more extensive description of the table to be displayed on the public database page.', verbose_name='Long description'),
        ),
        migrations.AlterField(
            model_name='table',
            name='metadata_access_level',
            field=models.CharField(choices=[('PRIVATE', 'Private - access must be granted by group'), ('INTERNAL', 'Internal - logged in users can access'), ('PUBLIC', 'Public - anonymous visitors can access')], default='PRIVATE', max_length=8, verbose_name='Metadata access level'),
        ),
        migrations.AlterField(
            model_name='table',
            name='related_identifiers',
            field=models.JSONField(blank=True, default=list, verbose_name='Related Identifiers'),
        ),
        migrations.AlterField(
            model_name='table',
            name='title',
            field=models.CharField(blank=True, default='', help_text='Human readable title of the table.', max_length=256, verbose_name='Title'),
        ),
        migrations.AlterField(
            model_name='table',
            name='type',
            field=models.CharField(choices=[('table', 'table'), ('view', 'view')], default='table', max_length=8, verbose_name='Type of table'),
        ),
        migrations.AlterField(
            model_name='table',
            name='utype',
            field=models.CharField(blank=True, default='', max_length=256, verbose_name='IVOA Utype'),
        ),
    ]
