# Generated by Django 4.2.20 on 2025-03-18 16:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_query', '0027_rename_job_to_query_job'),
    ]

    operations = [
        migrations.AlterField(
            model_name='queryarchivejob',
            name='files',
            field=models.JSONField(default=list, help_text='List of files in the archive.', verbose_name='Files'),
        ),
    ]
