{% extends 'core/wide.html' %}
{% load i18n %}

{% block wide %}

    <h1>{% trans 'TAP service' %}</h1>

    <ul>
        <li>
            <a href="{% url 'tap:sync-list' %}">{% trans 'sync' %}</a>
        </li>
        <li>
            <a href="{% url 'tap:async-list' %}">{% trans 'async' %}</a>
        </li>
    </ul>
    <ul>
        <li>
            <a href="{% url 'tap:resource' %}">{% trans 'VOResource Record' %}</a>
        </li>
        <li>
            <a href="{% url 'tap:capabilities' %}">{% trans 'VOSI capabilities' %}</a>
        </li>
        <li>
            <a href="{% url 'tap:tables' %}">{% trans 'VOSI tableset' %}</a>
        </li>
    </ul>
    <ul>
        <li>
            <a href="{% url 'tap:examples' %}">{% trans 'examples' %}</a>
        </li>
    </ul>

{% endblock %}
