{% load i18n %}

<p>
    {% blocktrans %}
    Please specify a local VOTable to upload and ingest as a new job into your user database. The job's table can be used in together with other tables in subsequent queries using JOIN and similar SQL commands. VOTables can be created using <a href="http://www.star.bris.ac.uk/~mbt/topcat/">TOPCAT</a> or <a href="http://docs.astropy.org/en/stable/io/votable/">astropy</a>.
    {% endblocktrans %}
</p>

<p>
    {% blocktrans %}
    Optionally, you can specify the name of the resulting database table and/or assign a run id, as with regular queries.
    {% endblocktrans %}
</p>
