{% extends 'core/page.html' %}
{% load i18n %}

{% block page %}

    <h1>{% trans "Password changed" %}</h1>

    <p>
        {% trans 'You successfully changed your password. Please use the new password to log in from now.' %}
    </p>

{% endblock %}
