{% extends 'core/page.html' %}
{% load i18n %}

{% block page %}

    <h1>{% trans "Password reset" %}</h1>

    <p>{% trans "Forgotten your password? Enter your email address below, and we'll send you an email allowing you to reset it." %}</p>

    <form method="post" action="{% url 'account_reset_password' %}" novalidate>
        {% csrf_token %}

        {{ form }}

        <input type="submit" class="btn btn-primary" value="{% trans 'Reset my password' %}" />
    </form>

{% endblock %}
