{% extends 'core/page.html' %}
{% load static %}
{% load i18n %}
{% load core_tags %}

{% block heading %}

<h1>{{ request.site.domain }}</h1>

{% endblock %}

{% block page %}

{% endblock %}

{% block sidebar %}

{% endblock %}
