# Generated by Django 4.2.19 on 2025-03-03 13:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_jobs', '0016_django2'),
    ]

    operations = [
        migrations.AlterField(
            model_name='job',
            name='job_type',
            field=models.CharField(choices=[('SYNC', 'Synchronous'), ('ASYNC', 'Asynchronous'), ('INTERFACE', 'Interface')], max_length=10),
        ),
    ]
