# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2017-07-25 11:17
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_metadata', '0009_arraysize'),
    ]

    operations = [
        migrations.AlterField(
            model_name='column',
            name='arraysize',
            field=models.IntegerField(blank=True, help_text='The length of variable length datatypes, e.g. varchar(256).', null=True, verbose_name='Arraysize'),
        ),
    ]
