# Generated by Django 3.2.12 on 2022-03-21 14:14

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_query', '0026_use_django_jsonfield'),
    ]

    operations = [
        migrations.RenameField(
            model_name='downloadjob',
            old_name='job',
            new_name='query_job',
        ),
        migrations.RenameField(
            model_name='queryarchivejob',
            old_name='job',
            new_name='query_job',
        ),
    ]
