# Generated by Django 2.2 on 2019-06-20 14:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_oai', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='record',
            name='resource_id',
            field=models.PositiveIntegerField(db_index=True, null=True, verbose_name='Resource id'),
        ),
        migrations.AddField(
            model_name='record',
            name='resource_type',
            field=models.CharField(db_index=True, default='', max_length=32, verbose_name='Resource type'),
            preserve_default=False,
        ),
    ]
