{% load static %}

<title>{{ request.site.name }}</title>

<meta charset="UTF-8" />
<meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=no" />

<meta property="og:title" content="{{ request.site.name }}" />
<meta property="og:url" content="{{ request.site.domain }}" />

<meta name="baseurl" content="{% url 'home' %}" />
<meta name="staticurl" content="{% static '' %}" />
<meta name="userid" content="{{ request.user.id|default_if_none:'' }}" />
<meta name="is_staff" content="{{ request.user.is_staff|default_if_none:'false'|lower }}" />

<link rel="shortcut icon" href="{% static 'core/img/favicon.png' %}" type="image/png" />
