# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2018-04-18 14:10
from __future__ import unicode_literals

from django.db import migrations
import jsonfield.fields


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_query', '0017_big_integer_fields'),
    ]

    operations = [
        migrations.AlterField(
            model_name='queryjob',
            name='metadata',
            field=jsonfield.fields.JSONField(blank=True),
        ),
    ]
