{% extends 'core/page.html' %}
{% load static %}
{% load i18n %}
{% load core_tags %}

{% block page %}
    <h1>{% trans 'Thank you for leaving a message for us!' %}</h1>

    <p>{% trans 'We will reply as soon as possible.' %}</p>
{% endblock %}
