# Generated by Django 2.1.4 on 2019-05-29 11:45

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_metadata', '0024_django2'),
    ]

    operations = [
        migrations.AddField(
            model_name='schema',
            name='published',
            field=models.DateField(blank=True, null=True, verbose_name='Published'),
        ),
        migrations.AddField(
            model_name='schema',
            name='updated',
            field=models.DateField(blank=True, null=True, verbose_name='Updated'),
        ),
        migrations.AddField(
            model_name='table',
            name='published',
            field=models.DateField(blank=True, null=True, verbose_name='Published'),
        ),
        migrations.AddField(
            model_name='table',
            name='updated',
            field=models.DateField(blank=True, null=True, verbose_name='Updated'),
        ),
    ]
