{% for schema in schemas %}
<li class="dropdown-submenu">
    <a class="dropdown-item" href="{% url 'metadata:schema' schema.name %}">
        <span class="d-flex">
            <span class="me-2">{{ schema.label }}</span>
            <i class="d-none d-lg-inline ms-auto bi bi-chevron-right"></i>
        </span>
    </a>

    <ul class="dropdown-menu">
        {% for table in schema.tables %}
        <li>
            <a class="dropdown-item" href="{% url 'metadata:table' schema.name table.name %}">{{ table.label }}</a>
        </li>
        {% endfor %}
    </ul>
</li>
{% endfor %}
