# -*- coding: utf-8 -*-
# Generated by Django 1.11.12 on 2018-04-13 11:43
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_query', '0016_rename_database_to_schema'),
    ]

    operations = [
        migrations.AlterField(
            model_name='queryjob',
            name='nrows',
            field=models.BigIntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='queryjob',
            name='size',
            field=models.BigIntegerField(blank=True, null=True),
        ),
    ]
