.codemirror .cm-content,.codemirror .cm-gutter{min-height:5rem}.success-indicator{height:1rem;opacity:0;transition:opacity .3s linear 2s}.success-indicator .bi{font-size:2rem}.success-indicator.show{opacity:1;transition:opacity .5s ease-in-out}
