export const messageStatus = {
  'ACTIVE': 'active',
  'CLOSED': 'closed',
  'SPAM': 'spam'
}

export const messageStatusBadge = {
  'ACTIVE': 'badge text-bg-primary',
  'CLOSED': 'badge text-bg-secondary',
  'SPAM': 'badge text-bg-danger'
}
