# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2017-07-18 09:21
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_query', '0010_queue_can_be_null'),
    ]

    operations = [
        migrations.AddField(
            model_name='queryjob',
            name='native_query',
            field=models.TextField(blank=True, null=True),
        ),
    ]
