# Generated by Django 3.2.11 on 2022-01-28 12:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_oai', '0004_alter_record_id'),
    ]

    operations = [
        migrations.AlterField(
            model_name='record',
            name='resource_id',
            field=models.BigIntegerField(db_index=True, null=True, verbose_name='Resource id'),
        ),
    ]
