# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2016-04-10 16:30
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('daiquiri_jobs', '0006_owner_blank_true'),
    ]

    operations = [
        migrations.CreateModel(
            name='QueryJob',
            fields=[
                ('job_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='daiquiri_jobs.Job')),
                ('tablename', models.CharField(max_length=256)),
                ('query', models.TextField()),
                ('queue', models.CharField(max_length=16)),
                ('nrows', models.IntegerField(blank=True, null=True)),
                ('size', models.IntegerField(blank=True, null=True)),
            ],
            options={
                'verbose_name_plural': 'QueryJobs',
                'permissions': (('view_queryjob', 'Can view QueryJob'),),
                'verbose_name': 'QueryJob',
            },
            bases=('daiquiri_jobs.job',),
        ),
    ]
