{% extends 'core/page.html' %}
{% load i18n %}
{% load static %}
{% load core_tags %}
{% load metadata_tags %}

{% block heading %}
    <h1 class="overflow-hidden">
        Metadata for {{ settings.SITE_TITLE }} databases
    </h1>
{% endblock %}

{% block page %}
    {% for schema in schemas %}
    <div class="card mb-3">
        <div class="card-header">
            <a href="{% url 'metadata:schema' schema.name %}">
                <i class="bi bi-database"></i> &nbsp;
                {% if schema.title %}
                {{ schema.title }} ({{ schema }})
                {% else %}
                {{ schema }}
                {% endif %}
            </a>
        </div>
        <div class="card-body">
            {% if schema.description %}
            {{ schema.description | markdown }}
            {% else %}
            {% trans 'No description has been provided for this schema.' %}
            {% endif %}
        </div>
        {% if schema.doi %}
        <div class="card-footer text-muted">
            <small>
            DOI: {% doi_link schema.doi %}
            </small>
        </div>
        {% endif %}
    </div>
    {% endfor %}
{% endblock %}
