{% extends 'core/page.html' %}
{% load i18n %}

{% block page %}

    <h1>{% trans "Sign Up Closed" %}</h1>

    <p>{% trans "We are sorry, but the sign up is currently closed." %}</p>

{% endblock %}
