# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-10-25 10:10
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_metadata', '0013_remove_directory'),
    ]

    operations = [
        migrations.RenameField(
            model_name='database',
            old_name='pid',
            new_name='doi',
        ),
        migrations.RenameField(
            model_name='table',
            old_name='pid',
            new_name='doi',
        ),
    ]
