$FontPathOpenSans: ".~npm-font-open-sans/fonts/";
@import "~npm-font-open-sans/open-sans";

$bootstrap-icons-font-dir: '~bootstrap-icons/font/fonts';
@import '~bootstrap-icons/font/bootstrap-icons.scss';

@import 'base/browser';
@import 'base/card';
@import 'base/codehilite';
@import 'base/fonts';
@import 'base/footer';
@import 'base/form';
@import 'base/forms';
@import 'base/layout';
@import 'base/link';
@import 'base/list';
@import 'base/modal';
@import 'base/navigation';
@import 'base/ordering';
@import 'base/table';
@import 'base/tooltip';
@import 'base/typography';
