# -*- coding: utf-8 -*-
# Generated by Django 1.11.9 on 2018-01-09 14:58
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_files', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='directory',
            name='depth',
            field=models.IntegerField(default=0),
        ),
        migrations.AlterField(
            model_name='directory',
            name='path',
            field=models.CharField(blank=True, help_text='Path of the directory.', max_length=256, verbose_name='Path'),
        ),
    ]
