# Generated by Django 2.1.4 on 2019-06-12 10:34

from django.db import migrations
import jsonfield.fields


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_query', '0022_blank_fields'),
    ]

    operations = [
        migrations.AddField(
            model_name='queryjob',
            name='uploads',
            field=jsonfield.fields.JSONField(blank=True, null=True),
        ),
    ]
