# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2016-11-01 13:42
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_jobs', '0006_owner_blank_true'),
    ]

    operations = [
        migrations.AddField(
            model_name='job',
            name='creation_time',
            field=models.DateTimeField(blank=True, null=True),
        ),
    ]
