# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2017-07-03 15:18
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_metadata', '0004_function_query_string'),
    ]

    operations = [
        migrations.AddField(
            model_name='database',
            name='attribution',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='database',
            name='license',
            field=models.CharField(blank=True, choices=[(b'CC0', b'CC0 1.0 Universal (CC0 1.0)'), (b'PD', b'Public Domain Mark'), (b'BY', b'Attribution 4.0 International (CC BY 4.0)'), (b'BY_SA', b'Attribution-ShareAlike 4.0 International (CC BY-SA 4.0)'), (b'BY_ND', b'Attribution-NoDerivatives 4.0 International (CC BY-ND 4.0)'), (b'BY_NC', b'Attribution-NonCommercial 4.0 International (CC BY-NC 4.0)'), (b'BY_NC_SA', b'Attribution-NonCommercial-ShareAlike 4.0 International (CC BY-NC-SA 4.0)'), (b'BY_NC_ND', b'Attribution-NonCommercial-NoDerivatives 4.0 International (CC BY-NC-ND 4.0)')], max_length=8, null=True),
        ),
        migrations.AddField(
            model_name='database',
            name='long_description',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='database',
            name='pid',
            field=models.URLField(blank=True, max_length=256, null=True),
        ),
        migrations.AddField(
            model_name='database',
            name='title',
            field=models.CharField(blank=True, max_length=256, null=True),
        ),
        migrations.AddField(
            model_name='table',
            name='attribution',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='table',
            name='license',
            field=models.CharField(blank=True, choices=[(b'CC0', b'CC0 1.0 Universal (CC0 1.0)'), (b'PD', b'Public Domain Mark'), (b'BY', b'Attribution 4.0 International (CC BY 4.0)'), (b'BY_SA', b'Attribution-ShareAlike 4.0 International (CC BY-SA 4.0)'), (b'BY_ND', b'Attribution-NoDerivatives 4.0 International (CC BY-ND 4.0)'), (b'BY_NC', b'Attribution-NonCommercial 4.0 International (CC BY-NC 4.0)'), (b'BY_NC_SA', b'Attribution-NonCommercial-ShareAlike 4.0 International (CC BY-NC-SA 4.0)'), (b'BY_NC_ND', b'Attribution-NonCommercial-NoDerivatives 4.0 International (CC BY-NC-ND 4.0)')], max_length=8, null=True),
        ),
        migrations.AddField(
            model_name='table',
            name='long_description',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='table',
            name='pid',
            field=models.URLField(blank=True, max_length=256, null=True),
        ),
        migrations.AddField(
            model_name='table',
            name='title',
            field=models.CharField(blank=True, max_length=256, null=True),
        ),
    ]
