# Generated by Django 3.2.12 on 2022-02-04 14:57

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_query', '0025_alter_example_id'),
    ]

    operations = [
        migrations.AlterField(
            model_name='queryarchivejob',
            name='files',
            field=models.JSONField(help_text='List of files in the archive.', verbose_name='Files'),
        ),
        migrations.AlterField(
            model_name='queryjob',
            name='metadata',
            field=models.JSONField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='queryjob',
            name='uploads',
            field=models.JSONField(blank=True, null=True),
        ),
    ]
