{% load i18n %}

<p>
    {% blocktrans %}
    Please specify a coordinate in right ascension (RA) and declination (DEC) and a cone radius. The query will result in objects that have coordinates in the search cone.
    {% endblocktrans %}
</p>

<p>
    {% blocktrans %}
    Optionally, you can specify the name of the resulting database table and/or assign a run id, to group associated queries in the job list. Please choose a queue with a suitable timeout for your query.
    {% endblocktrans %}
</p>
