# Generated by Django 2.1.3 on 2018-11-05 16:59

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_jobs', '0015_job_index'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='job',
            options={'ordering': ('start_time',), 'verbose_name': 'Job', 'verbose_name_plural': 'Jobs'},
        ),
    ]
