# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2017-04-11 12:29
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_query', '0007_queryjob_metadata'),
    ]

    operations = [
        migrations.AddField(
            model_name='queryjob',
            name='pid',
            field=models.IntegerField(blank=True, null=True),
        ),
    ]
