# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2017-04-13 09:31
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_jobs', '0007_creation_time'),
    ]

    operations = [
        migrations.AddField(
            model_name='job',
            name='error_summary',
            field=models.CharField(blank=True, max_length=256, null=True),
        ),
    ]
