{% extends 'core/base.html' %}
{% load static %}
{% load compress %}

{% block content %}
<div class="container">
    <main>
        {% include 'files/list-results.html' %}
    </main>
</div>
{% endblock %}
