.form-label {
    font-weight: bold;
}
.form-last {
    position: absolute;
    opacity: 0;
    top: 0;
    left: 0;
    height: 0;
    width: 0;
    z-index: -1;
}

.codemirror {
    .cm-line {
        padding: 0;
    }
    .cm-error {
        text-decoration: underline 3px red;
    }
    &.form-control {
        height: auto;
        padding: 0;

        .cm-editor {
            border-radius: 4px;
            border: 0;
        }
        .cm-focused {
            outline: 0;
        }
        .cm-content {
            padding: 0.375rem 0.75rem;
        }
        .cm-gutters {
            border-top-left-radius: 4px;
            border-bottom-left-radius: 4px;
        }
    }
}
