# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2016-11-01 13:34
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_query', '0003_query_language_and_actual_query'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='queryjob',
            options={'ordering': ('start_time',), 'permissions': (('view_queryjob', 'Can view QueryJob'),), 'verbose_name': 'QueryJob', 'verbose_name_plural': 'QueryJobs'},
        ),
        migrations.RenameField(
            model_name='queryjob',
            old_name='tablename',
            new_name='table_name',
        ),
        migrations.AddField(
            model_name='queryjob',
            name='database_name',
            field=models.CharField(default='daiquiri_user', max_length=256),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='queryjob',
            name='query_language',
            field=models.CharField(choices=[('mysql', 'MySQL SQL'), ('adql', 'ADQL')], max_length=8),
        ),
    ]
