{% extends 'core/base.html' %}
{% block content %}

<div class="container">
    <hgroup>
        {% block heading %}{% endblock %}
    </hgroup>

    <main>
        {% block wide %}{% endblock %}
    </main>
</div>

{% endblock %}
