# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2016-05-26 12:16
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_auth', '0006_profile_ordering'),
    ]

    operations = [
        migrations.AddField(
            model_name='profile',
            name='is_confirmed',
            field=models.BooleanField(default=True),
        ),
    ]
