{% extends 'core/wide.html' %}
{% load static %}

{% block css %}
<link rel="stylesheet" href="{% static 'core/css/bootstrap.css' %}" type="text/css" />
<link rel="stylesheet" href="{% static 'core/css/base.css' %}" type="text/css" />
<link rel="stylesheet" href="{% static 'metadata/css/management.css' %}" type="text/css" />
<link rel="stylesheet" href="{% static 'core/css/style.css' %}" type="text/css" />
{% endblock %}

{% block js %}
<script src="{% url 'javascript-catalog' %}"></script>
<script src="{% static 'metadata/js/management.js' %}" defer="defer"></script>
{% endblock %}

{% block wide %}

    <div id="app" class="management"></div>

{% endblock %}
