# Generated by Django 4.2.5 on 2023-09-20 07:37

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_contact', '0006_alter_contactmessage_id'),
    ]

    operations = [
        migrations.CreateModel(
            name='AnnouncementMessage',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(blank=True, max_length=100, null=True, verbose_name='Title')),
                ('announcement', models.TextField(verbose_name='Announcement')),
                ('announcement_type', models.CharField(choices=[('info', 'info'), ('warning', 'warning'), ('danger', 'urgent')], default='info', max_length=8, verbose_name='Announcement type')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('visible', models.BooleanField(default=False, verbose_name='Visible')),
                ('visibility_filter', models.CharField(default='no_filter', max_length=50, verbose_name='Visibility filter')),
            ],
            options={
                'verbose_name': 'Announcement message',
                'verbose_name_plural': 'Announcement messages',
                'ordering': ('-updated', 'title'),
            },
        ),
    ]
