# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2018-04-04 14:43
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_jobs', '0013_job_error_summary'),
    ]

    operations = [
        migrations.AlterField(
            model_name='job',
            name='run_id',
            field=models.CharField(blank=True, default='', max_length=64),
        ),
    ]
