{% extends 'core/wide.html' %}
{% load i18n %}
{% load core_tags %}

{% block wide %}

<h1>{% trans 'Stats overview' %}</h1>

<table class="table">
    <thead>
        <tr>
            <th>{% trans 'Resource type' %}</th>
            <th>{% trans '# records' %}</th>
            <th>{% trans '# users' %}</th>
            <th>{% trans '# client IP' %}</th>
            <th>{% trans '# size' %}</th>
        </tr>
    </thead>
    <tbody>
        {% for resource_type in resource_types %}
        <tr>
            <td>{{ resource_type.label }}</td>
            <td>{{ resource_type.count }}</td>
            <td>{{ resource_type.users }}</td>
            <td>{{ resource_type.client_ips }}</td>
            <td>{{ resource_type.size | filesizeformat }}</td>
        </tr>
        {% endfor %}
    </tbody>
</table>

{% endblock wide %}
