{% extends 'core/page.html' %}
{% load i18n %}

{% block page %}

    <h1>{% trans "Set new password" %}</h1>

    <p>
        {% trans "Please enter your new password twice so we can verify you typed it in correctly." %}
    </p>

    <form method="post" action="{% url 'account_set_password' %}" novalidate>
        {% csrf_token %}

        {{ form }}

        <input type="submit" class="btn btn-primary" value="{% trans 'Set password' %}" />
    </form>

{% endblock %}
