# Generated by Django 2.1.3 on 2018-11-05 16:59

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_stats', '0004_set_record_null'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='record',
            options={'ordering': ('-time',), 'verbose_name': 'Record', 'verbose_name_plural': 'Records'},
        ),
    ]
