# -*- coding: utf-8 -*-
# Generated by Django 1.11.10 on 2018-02-18 17:10
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_metadata', '0017_rename_database_to_schema'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='column',
            options={'ordering': ('table__schema__order', 'table__order', 'order'), 'permissions': (('view_column', 'Can view Column'),), 'verbose_name': 'Column', 'verbose_name_plural': 'Columns'},
        ),
    ]
