# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2017-02-14 13:20
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_metadata', '0003_groups'),
    ]

    operations = [
        migrations.AddField(
            model_name='function',
            name='query_string',
            field=models.CharField(default='', max_length=256),
            preserve_default=False,
        ),
    ]
