# Generated by Django 4.2.9 on 2024-01-22 09:13

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_stats', '0008_alter_record_resource'),
    ]

    operations = [
        migrations.AddField(
            model_name='record',
            name='size',
            field=models.PositiveBigIntegerField(blank=True, null=True),
        ),
    ]
