{% extends 'core/wide.html' %}
{% load static %}

{% block js %}
<script src="{% url 'javascript-catalog' %}"></script>
<script src="{% static 'serve/js/table.js' %}" defer="defer"></script>
{% endblock %}

{% block wide %}

    <h1>{{ table_title }} ({{ schema_name }}.{{ table_name }}) </h1>
    <p>
    {{ table_description | safe }}
    </p>

    <div
        id="app"
        class="serve"
        data-schema="{{ schema_name}}"
        data-table="{{ table_name}}">
    </div>

{% endblock %}
