# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-09-14 12:47
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_metadata', '0012_remove_directory_metadata_access_level'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='directory',
            name='groups',
        ),
        migrations.DeleteModel(
            name='Directory',
        ),
    ]
