# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2017-07-24 15:28
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_jobs', '0009_meta'),
    ]

    operations = [
        migrations.AddField(
            model_name='job',
            name='max_records',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='job',
            name='response_format',
            field=models.CharField(blank=True, max_length=64, null=True),
        ),
        migrations.AlterField(
            model_name='job',
            name='run_id',
            field=models.CharField(blank=True, max_length=64, null=True),
        ),
    ]
