# -*- coding: utf-8 -*-
# Generated by Django 1.11.9 on 2018-01-10 14:18
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import jsonfield.fields


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_jobs', '0012_meta'),
        ('daiquiri_query', '0014_downloadjob'),
    ]

    operations = [
        migrations.CreateModel(
            name='QueryArchiveJob',
            fields=[
                ('job_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='daiquiri_jobs.Job')),
                ('column_name', models.CharField(help_text='Column name for this download.', max_length=32, verbose_name='Column name')),
                ('files', jsonfield.fields.JSONField(help_text='List of files in the archive.', verbose_name='Files')),
                ('job', models.ForeignKey(help_text='QueryJob this ArchiveJob belongs to.', on_delete=django.db.models.deletion.CASCADE, related_name='archives', to='daiquiri_query.QueryJob', verbose_name='QueryJob')),
            ],
            options={
                'ordering': ('start_time',),
                'verbose_name': 'QueryArchiveJob',
                'verbose_name_plural': 'QueryArchiveJob',
                'permissions': (('view_queryarchivejob', 'Can view QueryArchiveJob'),),
            },
            bases=('daiquiri_jobs.job',),
        ),
        migrations.RemoveField(
            model_name='downloadjob',
            name='file_path',
        ),
    ]
