{% extends 'core/page.html' %}
{% load i18n %}

{% block page %}

    <h1>{% trans "Account pending" %}</h1>

    <p>{% trans "Thanks for signing up. Your account needs to be manually activated by an admin. This can take one or two days. You will receive an email when you can log in." %}</p>

{% endblock %}
