# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2016-07-07 08:36
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_metadata', '0002_published_for'),
    ]

    operations = [
        migrations.RenameField(
            model_name='column',
            old_name='published_for',
            new_name='groups',
        ),
        migrations.RenameField(
            model_name='database',
            old_name='published_for',
            new_name='groups',
        ),
        migrations.RenameField(
            model_name='function',
            old_name='published_for',
            new_name='groups',
        ),
        migrations.RenameField(
            model_name='table',
            old_name='published_for',
            new_name='groups',
        ),
    ]
