# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2016-03-31 08:39
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('daiquiri_jobs', '0001_job_model'),
    ]

    operations = [
        migrations.AlterField(
            model_name='job',
            name='execution_duration',
            field=models.PositiveIntegerField(blank=True, default=0),
        ),
    ]
